public inbox for linux-mtd@lists.infradead.org
 help / color / mirror / Atom feed
* [PATCH] [MTD] UBI: rename major_to_info()
@ 2007-03-21 16:18 Alexander Schmidt
  2007-03-21 16:21 ` Artem Bityutskiy
  0 siblings, 1 reply; 2+ messages in thread
From: Alexander Schmidt @ 2007-03-21 16:18 UTC (permalink / raw)
  To: Artem.Bityutskiy, linux-mtd@lists.infradead.org

The patch renames major_to_info() to major_to_device() to match the new
struct ubi_device.

Signed-off-by: Alexander Schmidt <alexs@linux.vnet.ibm.com>
---
 drivers/mtd/ubi/cdev.c |   10 +++++-----
 1 files changed, 5 insertions(+), 5 deletions(-)

--- dedekind-ubi-2.6.orig/drivers/mtd/ubi/cdev.c
+++ dedekind-ubi-2.6/drivers/mtd/ubi/cdev.c
@@ -50,12 +50,12 @@
 #endif
 
 /**
  * major_to_info - get UBI device object by character device major number.
  * @major: major number
  *
- * This function returns a pointer to the UBI description object.
+ * This function returns a pointer to the UBI device object.
  */
-static struct ubi_device *major_to_info(int major)
+static struct ubi_device *major_to_device(int major)
 {
 	int i;
 
@@ -124,7 +124,7 @@ static void revoke_exclusive(struct ubi_
 static int vol_cdev_open(struct inode *inode, struct file *file)
 {
 	struct ubi_volume_desc *desc;
-	const struct ubi_device *ubi = major_to_info(imajor(inode));
+	const struct ubi_device *ubi = major_to_device(imajor(inode));
 	int vol_id = iminor(inode) - 1;
 	int mode;
 
@@ -660,7 +660,7 @@ static int ubi_cdev_ioctl(struct inode *
 		return -EPERM;
 	}
 
-	ubi = major_to_info(imajor(inode));
+	ubi = major_to_device(imajor(inode));
 	if (IS_ERR(ubi))
 		return PTR_ERR(ubi);
 

^ permalink raw reply	[flat|nested] 2+ messages in thread

* Re: [PATCH] [MTD] UBI: rename major_to_info()
  2007-03-21 16:18 [PATCH] [MTD] UBI: rename major_to_info() Alexander Schmidt
@ 2007-03-21 16:21 ` Artem Bityutskiy
  0 siblings, 0 replies; 2+ messages in thread
From: Artem Bityutskiy @ 2007-03-21 16:21 UTC (permalink / raw)
  To: Alexander Schmidt; +Cc: Artem.Bityutskiy, linux-mtd@lists.infradead.org
@@ -50,12 +50,12 @@
 
 /**
- * major_to_info - get UBI device object by character device major number.
+ * major_to_device - get UBI device object by character device major number.
  * @major: major number
  *

On Wed, 2007-03-21 at 17:18 +0100, Alexander Schmidt wrote:
> The patch renames major_to_info() to major_to_device() to match the new
> struct ubi_device.
> 
> Signed-off-by: Alexander Schmidt <alexs@linux.vnet.ibm.com>
> ---
>  drivers/mtd/ubi/cdev.c |   10 +++++-----
>  1 files changed, 5 insertions(+), 5 deletions(-)

Committed, thanks.

-- 
Best regards,
Artem Bityutskiy (Битюцкий Артём)

^ permalink raw reply	[flat|nested] 2+ messages in thread

end of thread, other threads:[~2007-03-21 16:23 UTC | newest]

Thread overview: 2+ messages (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
2007-03-21 16:18 [PATCH] [MTD] UBI: rename major_to_info() Alexander Schmidt
2007-03-21 16:21 ` Artem Bityutskiy

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox